🚀 go-pugleaf

RetroBBS NetNews Server

Inspired by RockSolid Light RIP Retro Guy

1 total messages Started by Miron Cuperman Thu, 09 Apr 1992 19:10
gcc-2.1 50% slower with -O than 2.0
#349
Author: Miron Cuperman
Date: Thu, 09 Apr 1992 19:10
7 lines
643 bytes
Is it just me?  My (large) program runs 50% slower under gcc-2.1 -O than
with gcc-2.0 -O.  This is on a sparc.  Any ideas?  I'll see if I can
track down particular functions.
-- 
Forever, Miron Cuperman <miron@cs.sfu.ca>		(NeXTmail ok)

	Laissez faire.
Thread Navigation

This is a paginated view of messages in the thread with full content displayed inline.

Messages are displayed in chronological order, with the original post highlighted in green.

Use pagination controls to navigate through all messages in large threads.

Back to All Threads